@@ -41,7 +41,6 @@ extern struct plist	*mainlist;	/* list of all schedule entries */
 
 static BOOL		have_shell;	/* message popup exists if TRUE */
 static Widget		shell;		/* popup menu shell */
-static XtIntervalId	timer_id;	/* identifies 1-second timer */
 static Widget		time_w;		/* current time display */
 static Widget		adjust_w;	/* time adjustment text widget */
 static Widget		tzone_w;	/* timezone text widget */
@@ -87,7 +86,7 @@ static void sec_timer_callback(
 {
 	if (have_shell) {
 		print_times();
-		timer_id = XtAppAddTimeOut(app, 1000, sec_timer_callback, 0);
+		XtAppAddTimeOut(app, 1000, sec_timer_callback, 0);
 	}
 }
 
@@ -494,7 +493,7 @@ void create_adjust_popup(void)
 	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
 			done_callback, (XtPointer)shell);
 	have_shell = TRUE;
-	timer_id = XtAppAddTimeOut(app, 1000, sec_timer_callback, 0);
+	XtAppAddTimeOut(app, 1000, sec_timer_callback, 0);
 }
 
 
