@@ -13,7 +13,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-#include <varargs.h>
 #include <Xm/Xm.h>
 #include <Xm/MainW.h>
 #include <Xm/Form.h>
@@ -567,7 +566,7 @@ static void filemenu_callback(
 			create_error_popup(mainmenu.cal, 0, errmsg);
 		if (can_edit_appts()) {
 			read_mainlist();
-			update_all_listmenus();
+			update_all_listmenus(TRUE);
 			redraw_all_views();
 		}
 		break; }
@@ -595,7 +594,7 @@ static void delpast_callback(
 {
 	if (can_edit_appts())
 		if (item < 5 && recycle_all(mainlist, TRUE, period[item])) {
-			update_all_listmenus();
+			update_all_listmenus(TRUE);
 			redraw_all_views();
 		}
 }
@@ -695,7 +694,7 @@ static void search_callback(
 		break;
 
 	  case 7:						/* One file */
-		create_user_sel_popup(menubar, 0, (BOOL (*)())list_by_user);
+		create_user_sel_popup(menubar, -1, (BOOL (*)())list_by_user);
 		break;
 
 	  case 8:						/* Search */
