@@ -741,7 +741,7 @@ static void flag_callback(
 		create_view('m');
 	}
 	mainlist->modified = TRUE;
-	update_all_listmenus();
+	update_all_listmenus(TRUE);
 	redraw_all_views();
 	print_icon_name();
 	if (config.smallmonth)
