@@ -28,11 +28,7 @@ typedef int		Boolean;		/* open Motif */
 #include <stdlib.h>
 #include <errno.h>
 #include <unistd.h>
-#ifdef VARARGS
-#include <varargs.h>
-#else
 #include <stdarg.h>
-#endif
 #include <sys/types.h>
 #include <sys/wait.h>
 #include <sys/stat.h>
@@ -101,6 +97,8 @@ static void sighand		(int);
 static void usage		(void);
 static void alert		(struct entry *, int);
 void create_error_popup		(void *, int, char *, ...);
+time_t read_last_alarm          (void);
+void update_last_alarm          (void);
 
 char			*progname;	/* argv[0] */
 extern char		lockpath[];	/* lockfile path (from lock.c) */
@@ -108,9 +106,9 @@ struct config		config;		/* global configuration data */
 struct plist		*mainlist;	/* list of all schedule entries */
 extern time_t		cutoff;		/* all triggers before this are done */
 static BOOL		reread;		/* caught SIGHUP, re-read mainlist */
-static BOOL		debug;		/* print debugging information */
+BOOL			debug;		/* print debugging information */
 static BOOL		opt_t;		/* TRUE if -t (tty) */
-extern int		errno;		/* system error */
+static time_t		last_alarm;	/* Last time alarm was checked for */
 
 int			curr_year;	/* dummy for DST calculating routines*/
 Widget			mainwindow;	/* dummy for error popup in network.c*/
@@ -134,6 +132,7 @@ int main(
 	BOOL			opt_K = FALSE;	/* TRUE if -K (kill & exit) */
 	BOOL			opt_l = TRUE;	/* TRUE if -l (watch logout) */
 	BOOL			opt_s = FALSE;	/* TRUE if -s (silent) */
+	BOOL			opt_p = FALSE;	/* TRUE if -p (missed alarms) */
 	struct utmp		*u;		/* for scanning /etc/utmp */
 	struct passwd		*pw = 0;	/* user's password entry */
 	BOOL			got_login=FALSE;/* was user ever logged in? */
@@ -157,6 +156,7 @@ int main(
 				  case 'L': opt_l = FALSE; break;
 				  case 's': opt_s = TRUE;  break;
 				  case 't': opt_t = TRUE;  break;
+				  case 'p': opt_p = TRUE;  break;
 				  default:  usage();
 				}
 		} else
@@ -199,7 +199,8 @@ int main(
 		(void)unlink(lockpath);
 		exit(0);
 	}
-
+	if (opt_p)
+		ancient = read_last_alarm();
 
 	/*
 	 * main loop
@@ -228,9 +229,11 @@ int main(
 	    }
 	    (void)recycle_all(mainlist, FALSE, 0);
 
+	    cutoff = now - ancient;
+
 	    if (!(opt_s && !logged_in)) {
 		set_tzone();
-		now = get_time();
+		last_alarm = now = get_time();
 		reason = find_next_trigger(mainlist, now, &entry, &twait);
 		if (reason && twait <= 0) {
 		    alert(entry, reason);
@@ -238,7 +241,6 @@ int main(
 		    continue;
 		}
 	    }
-	    cutoff = now - ancient;
 	    ancient = 0;
 	    if (!reason)
 		twait = HIBERNATE;
@@ -443,6 +445,28 @@ static void send_mail(
 }
 
 
+/*
+ * DateBk4 (a PalmPilot application) synced messages may have extra info.
+ * Skip it. By Johan Vromans <jvromans@squirrel.nl>
+ */
+
+static char *get_message(
+	struct entry	*entry)
+{
+	if (entry->message) {
+		char *msg = entry->message;
+		int l = strlen(msg);
+		if (l >= 20 && msg[0] == '#' && msg[1] == '#' && msg[19]=='\n')
+			if (l > 20)
+				return(msg + 20);
+			else
+				return(NULL);
+		else
+			return(msg);
+	}
+	return(NULL);
+}
+
 
 /*
  * execute a program, and pass the entry's message or note text as standard
@@ -571,8 +595,11 @@ static void exec_program(
 		exit(0);
 	}
 	pid = 1;
-	msg = entry->message ? entry->message :
-	      entry->note    ? entry->note    : "";
+
+	/* DateBk4 (a PalmPilot application) synced messages may have rather */
+	/* uninteresting messages. From Johan Vromans <jvromans@squirrel.nl> */
+	if (!(msg = get_message(entry)))
+		msg = entry->note ? entry->note : "";
 	msgsize = strlen(msg);
 
 	if (msgsize <= PIPE_MAX ||		/* child 2, feeds child 1 */
@@ -588,8 +615,6 @@ static void exec_program(
 	}
 }
 
-
-
 /*
  * write script to a file. The script name is generated from the process ID,
  * so that reaper() knows which script to delete after this process terminates.
@@ -932,7 +957,7 @@ static char *get_subtitle(
 				entry->length/3600, (entry->length/60)%60,
 				time/60, time%60, ampm);
 	}
-	if (entry->note && entry->message) {
+	if (entry->note && get_message(entry)) {
 		if (*msg)
 			strcat(msg, " - ");
 		strncpy(msg+strlen(msg), entry->note, 80);
@@ -991,6 +1016,7 @@ static void sighand(
 	} else {					/* die */
 		(void)unlink(lockpath);
 		fprintf(stderr, _("%s: killed with signal %d\n"),progname,sig);
+		update_last_alarm();
 		exit(0);
 	}
 }
@@ -1001,32 +1027,16 @@ static void sighand(
  * print to stderr.
  */
 
-#ifndef VARARGS
 void create_error_popup(
 	void		*widget,
 	int		error,
 	char		*fmt, ...)
 {
 	va_list		parm;
-#else
-void create_error_popup(
-	void		*widget,
-	int		error,
-	char		*fmt,
-	int		a,
-	int		b,
-	int		c,
-	int		d)
-{
-#endif
 	fprintf(stderr, "%s: ", progname);
-#ifndef VARARGS
 	va_start(parm, fmt);
 	vfprintf(stderr, fmt, parm);
 	va_end(parm);
-#else
-	fprintf(stderr, fmt, a, b, c, d);
-#endif
 #	if defined(sgi) || defined(_sgi)
 	if (error) {
 		fprintf(stderr, "\n");
@@ -1036,6 +1046,53 @@ void create_error_popup(
 }
 
 
+/*
+ * record the last time an alarm was check for in the ~/.pland file so it can
+ * be referenced on the next run, by Brian L. Shaver <shaker.lxxv@verizon.net>
+ */
+
+void update_last_alarm(void)
+{
+	FILE		*fp;
+
+	if (fp = fopen(resolve_tilde(PLAND_PATH), "w")) {
+		fprintf(fp, "%ld", last_alarm);
+		if (debug)
+			printf(_("recorded last alarm: %ld\n"), last_alarm);
+		fclose(fp);
+	} else
+		if (debug)
+			printf(_("unable to update last alarm\n"));
+}
+
+
+/*
+ * read the last alarm check time so that alarms which may have been
+ * missed can be picked up when pland is restarted.
+ */
+
+time_t read_last_alarm(void)
+{
+	time_t		result;
+	FILE		*fp;
+
+	if (fp = fopen(resolve_tilde(PLAND_PATH), "r")) {
+		fscanf(fp,"%ld",&result);
+		if (debug)
+			printf(_("reading last alarm: %ld\n"), result);
+		result = get_time() - result;	/* compute cutoff difference */
+		if (debug)
+			printf(_("initial alarm cutoff: %ld\n"), result);
+		fclose(fp);
+	} else {
+		result = ANCIENT;
+		if (debug)
+			printf(_("last alarm not present\n"));
+	}
+	return(result);
+}
+
+
 /*
  * usage message if incorrect options are given
  */
@@ -1052,6 +1109,7 @@ static void usage(void)
 	fprintf(stderr, _("-s\twatch utmp and sleep while user is logged out\n"));
 	fprintf(stderr, _("-l\twatch utmp and exit when user logs out\n"));
 	fprintf(stderr, _("-L\tdon't watch utmp (utmp is often buggy)\n"));
+	fprintf(stderr, _("-p\treport missed alarms when starting.\n"));
 	fprintf(stderr,
 #	ifdef RABBITS
 		_("-L is the default. Try -l if you get too many pland's.\n"));
