@@ -42,7 +42,6 @@ void build_day(
 	time_t		date;		/* midnight of calculated day */
 	int		wday;		/* day counter, 0..NDAYS-1 */
 	int		nlines=0;	/* total number of bar columns */
-	struct tm	*tm;		/* check if wday in same year*/
 	struct entry	*ep;		/* ptr to entry in mainlist */
 	BOOL		found;		/* TRUE if lookup succeeded */
 	struct lookup	lookup;		/* result of entry lookup */
@@ -69,7 +68,6 @@ void build_day(
 	for (wday=0; wday < c->day_ndays; wday++, date+=86400) {
 		day.nlines[wday] = 0;
 		day.tree[wday] = 0;
-		tm = time_to_tm(date);
 		found = lookup_entry(&lookup, mainlist, date, TRUE, FALSE,
 								'd', -1);
 		for (; found; found = lookup_next_entry(&lookup)) {
