@@ -45,6 +45,7 @@ extern struct user	*user;		/* user list (from file_r.c) */
 extern int		nusers;		/* number of users in user list */
 time_t			cutoff;		/* no alarms before this time */
 					/* (used by daemon only) */
+extern BOOL		debug;		/* print debugging information */
 
 
 /*----------------------------------- user mgmt -----------------------------*/
@@ -121,10 +122,6 @@ static int sort_same_time(
 	struct plist		*list,		/* list to adjust */
 	int			n)		/* index to proposed new pos */
 {
-	static int		seq;		/* ensures stable sort */
-
-	if (!entry->seq)
-		entry->seq = ++seq;
 	while (n > 0 && list->entry[n-1].time == entry->time
 		     && list->entry[n-1].seq > entry->seq)
 		n--;
@@ -145,6 +142,7 @@ static int sort_same_time(
  * trashing the chain.
  */
 
+
 int add_entry(
 	struct plist		**list,		/* list to add to */
 	struct entry		*entry)		/* entry to add */
@@ -156,6 +154,7 @@ int add_entry(
 	int			n;		/* index of new entry in list*/
 	register struct entry	*p, *q;		/* entry copy pointers */
 	register int		i;		/* entry copy counter */
+	static unsigned int	next_seq;	/* next entry->seq number */
 
 	if (*list) {
 		(*list)->locked++;
@@ -195,6 +194,7 @@ int add_entry(
 	new->repeating = 0;
 	new->modified = TRUE;
 	new->locked--;
+	entry->seq = next_seq++;
 	return(n);
 }
 
@@ -650,8 +650,14 @@ int find_next_trigger(
 	if (!list)
 		return(0);
 
+	/*
 	t = time % 86400;
 	t = t < 3*3600 ? time - t : time - 3*3600;
+	*/
+	t = cutoff;
+	if (debug)
+		printf(_("searching for next trigger from: %ld\n"),t);
+
 	for (found = lookup_entry(&lookup, list, t, TRUE, FALSE, '*', -1);
 	     found;
 	     found = lookup_next_entry(&lookup)) {
@@ -660,11 +666,11 @@ int find_next_trigger(
 		if (trigger > time+2*86400)
 			break;
 		ep = list->entry + lookup.index;
-		if (trigger + ep->length < time - ANCIENT)
+		if (trigger + ep->length < cutoff)
 			continue;
-		if (!ep->triggered && trigger > time-ANCIENT
+		if (!ep->triggered && trigger > cutoff
 				   && trigger < time
-				   && trigger + ep->length > time-ANCIENT)
+				   && trigger + ep->length > cutoff)
 			ep->triggered = 2;
 		for (i=0; i < NEXC; i++)
 			if (ep->except[i] == trigger - trigger % 86400)
