@@ -68,7 +68,7 @@ static void got_new_user(
 	edit.changed = TRUE;
 	edit.editing = TRUE;
 	confirm_new_entry();
-	update_all_listmenus();
+	update_all_listmenus(TRUE);
 	sensitize_edit_buttons();
 }
 
@@ -126,12 +126,14 @@ void got_entry_press(
 				create_error_popup(lw->shell, 0, "%s\n%s\n",
 					_("Somebody else is editing this "\
 					  "entry. Please try again later."));
+				update_all_listmenus(FALSE);
 				return;
 			}
 		} else {
 			if (x != SC_DATE && x != SC_TIME && x != SC_NOTE) {
 				create_error_popup(lw->shell, 0,
 					_("Please enter time or date first"));
+				update_all_listmenus(FALSE);
 				return;
 			}
 			clone_entry(&edit.entry, (struct entry *)0);
@@ -154,7 +156,7 @@ void got_entry_press(
 		ep->suspended = !on;
 		edit.changed = TRUE;
 		sensitize_edit_buttons();
-		update_all_listmenus();
+		update_all_listmenus(FALSE);
 		break;
 
 	  case SC_USER:
@@ -295,7 +297,6 @@ void got_entry_press(
 		edit.changed = TRUE;
 		edit.entry.suspended = FALSE;
 		sensitize_edit_buttons();
-		/* update_all_listmenus(); */
 	}
 }
 
@@ -315,8 +316,6 @@ void confirm_new_entry(void)
 	BOOL		changed;
 	unsigned int	new_file;
 	unsigned int	old_file = edit.entry.file;
-	struct tm	new;
-	struct tm	old;
 	struct user	*u;
 	BOOL            addentry = TRUE;
 
@@ -329,8 +328,6 @@ void confirm_new_entry(void)
 	destroy_recycle_popup();
 	destroy_except_popup();
 	changed = edit.editing && edit.changed;
-	new = *time_to_tm(edit.entry.time);
-	old = new;
 	if (changed) {
 		struct entry *ep = 0;
 		mainlist->locked++;
@@ -376,10 +373,8 @@ void confirm_new_entry(void)
 				edit.entry.id   = old_id;
 			}
 		}
-		if (ep) {
-			old = *time_to_tm(ep->time);
+		if (ep)
 			delete_entry(mainlist, ep - mainlist->entry);
-		}
 		if (addentry) {
 			(void)add_entry(&mainlist, &edit.entry);
 			rebuild_repeat_chain(mainlist);
@@ -392,7 +387,8 @@ void confirm_new_entry(void)
 	if (interactive) {
 		sensitize_edit_buttons();
 		if (changed) {
-			update_all_listmenus();
+			/* new entry vanishes from edit menu if arg is FALSE */
+			update_all_listmenus(TRUE);
 			redraw_all_views();
 			mainlist->modified = TRUE;
 			if (last_x_timer != (time_t)-1 &&
