@@ -6,8 +6,8 @@
  *
  *	destroy_all_listmenus()		Destroy all list menus. This is done
  *					when the warning column width changes.
- *	update_all_listmenus()		Redraw all list menus. This is
- *					necessary donee often.
+ *	update_all_listmenus(reeval)	Redraw all list menus. Also rebuild if
+ *					reeval==TRUE.
  *	create_entry_widgets(w, nentries)
  *					Creates all widgets in a list menu
  *					that make up the entry list array. If
@@ -185,31 +185,32 @@ static struct listmenu *create_list_menu(
 static void destroy_list_menu(
 	struct listmenu	*lw)
 {
-	struct tm	*tm;		/* time to m/d/y conv */
-
 	edit_list_button(0, lw, 0, 0);
 	XmToggleButtonSetState(lw->pin, lw->pinned = FALSE, FALSE);
 	XtPopdown(lw->shell);
 	lw->popped = FALSE;
 	confirm_new_entry();
-	tm = time_to_tm(lw->time);
 	destroy_sublist(lw);
 }
 
 
 /*
  * the main list changed, and all list menus must be re-evaluated and
- * redrawn. This routine is here because this is the only file that
- * knows about all list menus.
+ * redrawn. Reevaluation can be disabled by setting reeval to FALSE; this
+ * is useful if an appointment got changed but we don't want it to bounce
+ * to a different place in the list or disappear altogether. This routine
+ * is here because this is the only file that knows about all list menus.
  */
 
-void update_all_listmenus(void)
+void update_all_listmenus(
+	BOOL		reeval)		/* just redraw or recreate too? */
 {
 	struct listmenu	*scan;		/* popup scan pointer */
-
+	
 	for (scan=listmenu; scan; scan=scan->next)
 		if (scan->popped) {
-			create_sublist(mainlist, scan);
+			if (reeval)
+				create_sublist(mainlist, scan);
 			draw_list(scan);
 		}
 }
@@ -234,7 +235,7 @@ void destroy_all_listmenus(void)
 			XTDESTROYWIDGET(scan->shell);
 		free((char *)scan);
 	}
-	listmenu = 0;
+	listmenu      = 0;
 	edit.menu     = 0;
 	edit.srcentry = 0;
 }
@@ -1005,7 +1006,7 @@ static void list_delete(
 
 	rebuild_repeat_chain(mainlist);
 	/* draw_list(edit.menu); 1.8.4 */
-	update_all_listmenus();
+	update_all_listmenus(TRUE);
 	redraw_all_views();
 }
 
