@@ -75,7 +75,7 @@ static void fillout_except_menu(void)
 #ifdef XmCSimpleOptionMenu
 	XtSetArg(args[0], XmNforeground, color[col]);
 	XtSetArg(args[1], XmNmenuHistory, acol_sw[(int)edit.entry.acolor]);
-	XtSetValues(XmOptionButtonGadget(acol_w), args, 2);
+	XtSetValues(acol_w, args, 2);
 #else
 	XtSetArg(args[0], XmNforeground, color[col]);
 	XtSetValues(acol_w, args, 1);
