@@ -12,18 +12,23 @@
 
 #include <X11/Xos.h>
 #include <stdio.h>
-#include <ctype.h>
-#include <assert.h>
 #include <stdlib.h>
+#include <ctype.h>
+#include <time.h>
+#include <assert.h>
 #include <sys/stat.h>
 #include <Xm/Xm.h>
 #include "config.h"
 
+#ifdef GROK
+#include "proto.h"
+#endif
+#ifdef PLANGROK
+#include "cal.h"
+#endif
 #if defined(GROK) || defined(PLANGROK)
-
 #include "grok.h"
 #include "form.h"
-#include "proto.h"
 
 #define CHUNK	32			/* alloc 32 new rows at a time */
 
