@@ -35,7 +35,6 @@ char *itemname[NITEMS] = {
 	"None", "Label", "Print", "Input", "Time", "Note", "Choice", "Flag",
 	"Button", "Summary", "Chart" };
 
-extern int	errno;
 extern char	*progname;		/* argv[0] */
 extern Widget	toplevel;		/* top-level shell for error popups */
 
@@ -313,7 +312,7 @@ BOOL read_form(
 					fprintf(stderr,
 						"%s: %s: bad item type %s\n",
 						progname, path, p);
-				item->type = i;
+				item->type = (ITYPE)i;
 			}
 			else if (!strcmp(key, "name"))
 					STORE(item->name, p);
@@ -338,7 +337,7 @@ BOOL read_form(
 			else if (!strcmp(key, "defsort"))
 					item->defsort = atoi(p) ? TRUE : FALSE;
 			else if (!strcmp(key, "timefmt"))
-					item->timefmt = atoi(p);
+					item->timefmt = (TIMEFMT)atoi(p);
 			else if (!strcmp(key, "code"))
 					STORE(item->flagcode, p);
 			else if (!strcmp(key, "codetxt"))
@@ -346,7 +345,7 @@ BOOL read_form(
 			else if (!strcmp(key, "label"))
 					STORE(item->label, p);
 			else if (!strcmp(key, "ljust"))
-					item->labeljust = atoi(p);
+					item->labeljust = (JUST)atoi(p);
 			else if (!strcmp(key, "lfont"))
 					item->labelfont = atoi(p);
 			else if (!strcmp(key, "gray"))
@@ -366,7 +365,7 @@ BOOL read_form(
 			else if (!strcmp(key, "maxlen"))
 					item->maxlen = atoi(p);
 			else if (!strcmp(key, "ijust"))
-					item->inputjust = atoi(p);
+					item->inputjust = (JUST)atoi(p);
 			else if (!strcmp(key, "ifont"))
 					item->inputfont = atoi(p);
 			else if (!strcmp(key, "p_act"))
