@@ -18,15 +18,20 @@
 #include <X11/Xos.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <time.h>
 #include <errno.h>
 #include <Xm/Xm.h>
 #include "config.h"
 
+#ifdef GROK
+#include "proto.h"
+#endif
+#ifdef PLANGROK
+#include "cal.h"
+#endif
 #if defined(GROK) || defined(PLANGROK)
-
 #include "grok.h"
 #include "form.h"
-#include "proto.h"
 
 #define CHUNK		10		/* alloc 10 new item ptrs at a time */
 #define XSNAP(x)	((x)-(x)%form->xg)
@@ -536,7 +541,7 @@ BOOL item_create(
 					}
 				}
 		}
-		sprintf(buf, "item%d", item->column);
+		sprintf(buf, "item%d", (int)item->column);
 		item->name = mystrdup(buf);
 	}
 	return(TRUE);
