@@ -20,7 +20,8 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void text_callback(), done_callback();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void text_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -42,7 +43,7 @@ static Widget		text;		/* search string */
  * It's too much trouble to keep them for next time.
  */
 
-void destroy_goto_popup()
+void destroy_goto_popup(void)
 {
 	if (have_shell)
 		XtPopdown(shell);
@@ -56,7 +57,7 @@ void destroy_goto_popup()
  * ensures that it comes up with the same text.
  */
 
-void create_goto_popup()
+void create_goto_popup(void)
 {
 	Widget			form, w;
 	Arg			args[20];
@@ -70,7 +71,7 @@ void create_goto_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Goto Date",
+	shell = XtCreatePopupShell(_("Goto Date"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -79,14 +80,15 @@ void create_goto_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("gotoform", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"goto");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"goto");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNtopOffset,		16);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("Date to switch to:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Date to switch to:"), xmLabelWidgetClass,
 			form, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -103,8 +105,8 @@ void create_goto_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	text = XtCreateManagedWidget(" ", xmTextFieldWidgetClass,
 			form, args, n);
-	XtAddCallback(text, XmNactivateCallback, text_callback,
-						(XtPointer)NULL);
+	XtAddCallback(text, XmNactivateCallback, (XtCallbackProc)
+			text_callback, (XtPointer)NULL);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
 	XtSetArg(args[n], XmNtopWidget,		text);			n++;
@@ -112,9 +114,10 @@ void create_goto_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	16);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Cancel", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Cancel"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -126,14 +129,15 @@ void create_goto_popup()
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	16);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, help_callback,(XtPointer)"goto");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"goto");
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
 	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+			(XtCallbackProc)done_callback, (XtPointer)shell);
 	have_shell = TRUE;
 }
 
@@ -144,20 +148,20 @@ void create_goto_popup()
  */
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_goto_popup();
 }
 
 
 /*ARGSUSED*/
-static void text_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void text_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	String string = XmTextFieldGetString(widget);
 	if (*string) {
