@@ -15,10 +15,10 @@
  */
 
 #include <stdio.h>
-#ifndef NEWSOS4
-#ifdef STDLIBMALLOC
 #include <stdlib.h>
-#else
+#include <time.h>
+#ifndef NEWSOS4
+#ifndef STDLIBMALLOC
 #include <malloc.h>
 #endif
 #endif
@@ -36,13 +36,15 @@
 #include <X11/cursorfont.h>
 #include "cal.h"
 
-static void		done_callback(), context_callback();
-static char		*get_text();
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void context_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static char *get_text		(char *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
 extern XFontStruct	*font[NFONTS];	/* fonts: FONT_* */
 extern Pixel		color[NCOLS];	/* colors: COL_* */
+extern struct config	config;		/* global configuration data */
 
 static BOOL		have_shell;	/* message popup exists if TRUE */
 static Widget		shell;		/* popup menu shell */
@@ -52,7 +54,7 @@ static Widget		shell;		/* popup menu shell */
  * destroy the help popup. Remove it from the screen, and destroy its widgets.
  */
 
-void destroy_help_popup()
+void destroy_help_popup(void)
 {
 	if (have_shell) {
 		XtPopdown(shell);
@@ -62,15 +64,14 @@ void destroy_help_popup()
 }
 
 
-
 /*
  * look up the help text for <topic> and create a window containing the text.
  */
 
 /*ARGSUSED*/
-void help_callback(parent, topic)
-	Widget			parent;
-	char			*topic;
+void help_callback(
+	Widget			parent,
+	char			*topic)
 {
 	static BOOL		have_fontlist;
 	static XmFontList	fontlist;
@@ -100,7 +101,7 @@ void help_callback(parent, topic)
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Help", applicationShellWidgetClass,
+	shell = XtCreatePopupShell(_("Help"), applicationShellWidgetClass,
 			toplevel, args, n);	
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -109,8 +110,8 @@ void help_callback(parent, topic)
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("helpform", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)help_callback,
-							(XtPointer)"help");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"help");
 
 							/*-- buttons --*/
 	n = 0;
@@ -119,11 +120,12 @@ void help_callback(parent, topic)
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Dismiss", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Dismiss"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)help_callback,
-						(XtPointer)"help_done");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"help_done");
 	n = 0;
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	8);			n++;
@@ -131,11 +133,12 @@ void help_callback(parent, topic)
 	XtSetArg(args[n], XmNrightWidget,	w);			n++;
 	XtSetArg(args[n], XmNrightOffset,	8);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Context", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Context"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, context_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)help_callback,
-							(XtPointer)"help");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			context_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"help");
 
 							/*-- text --*/
 	n = 0;
@@ -161,33 +164,33 @@ void help_callback(parent, topic)
 	XtVaSetValues(w, XmNbackground,	color[COL_CALBACK], NULL);
 	XtVaSetValues(w, XmNforeground,	color[COL_STD],     NULL);
 	XtManageChild(w);
-	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)help_callback,
-							(XtPointer)"help");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"help");
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 	have_shell = TRUE;
 	free(message);
 }
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_help_popup();
 }
 
 
 /*ARGSUSED*/
-static void context_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void context_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	Widget w;
 	Cursor cursor = XCreateFontCursor(display, XC_question_arrow);
@@ -200,10 +203,11 @@ static void context_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static char *get_text(topic)
-	char			*topic;
+static char *get_text(
+	char			*topic)
 {
 	FILE			*fp;		/* help file */
+	char			file[1024];	/* help file name */
 	char			line[1024];	/* line buffer (and filename)*/
 	char			*text;		/* text buffer */
 	int			textsize;	/* size of text buffer */
@@ -214,14 +218,18 @@ static char *get_text(topic)
 	if (!(text = (char *)malloc(textsize = 4096)))
 		return(0);
 	*text = 0;
-	if (!find_file(line, HELP_FN, FALSE) || !(fp = fopen(line, "r"))) {
-		sprintf(text, "Sorry, no help available,\n%s not found",
+	if (config.language)
+		sprintf(file, "%.767s.%.255s", HELP_FN, config.language);
+	if (!(config.language &&
+	      find_file(line, file,    FALSE) && (fp = fopen(line, "r"))) &&
+	    !(find_file(line, HELP_FN, FALSE) && (fp = fopen(line, "r")))) {
+		sprintf(text, _("Sorry, no help available,\n%s not found"),
 								HELP_FN);
 		return(text);
 	}
 	for (;;) {					/* find topic */
 		if (!fgets(line, 1024, fp)) {
-			strcpy(text, "Sorry, no help available");
+			strcpy(text, _("Sorry, no help available"));
 			return(text);
 		}
 		if (line[0] != '%' || line[1] != '%')
