@@ -22,8 +22,10 @@
 #include <Xm/Protocols.h>
 #include "cal.h"
 
-static void mode_callback(), text_callback(),
-	    search_callback(), done_callback();
+static void mode_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void text_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void search_callback	(Widget, int, XmToggleButtonCallbackStruct *);
+static void done_callback	(Widget, int, XmToggleButtonCallbackStruct *);
 
 extern Display		*display;	/* everybody uses the same server */
 extern Widget		toplevel;	/* top-level shell for icon name */
@@ -43,7 +45,7 @@ int			search_mode=1;	/* 0=case sensitive, 1=ins., 2=regex */
  * It's too much trouble to keep them for next time.
  */
 
-static void destroy_keyword_popup()
+static void destroy_keyword_popup(void)
 {
 	if (have_shell) {
 		if (search_string)
@@ -61,7 +63,7 @@ static void destroy_keyword_popup()
  * that it comes up with the same defaults.
  */
 
-void create_keyword_popup()
+void create_keyword_popup(void)
 {
 	Widget			form, radio, w;
 	Arg			args[20];
@@ -75,7 +77,7 @@ void create_keyword_popup()
 	n = 0;
 	XtSetArg(args[n], XmNdeleteResponse,	XmDO_NOTHING);		n++;
 	XtSetArg(args[n], XmNiconic,		False);			n++;
-	shell = XtCreatePopupShell("Keyword Search",
+	shell = XtCreatePopupShell(_("Keyword Search"),
 			applicationShellWidgetClass, toplevel, args, n);
 #	ifdef EDITRES
 	XtAddEventHandler(shell, (EventMask)0, TRUE, 
@@ -84,7 +86,8 @@ void create_keyword_popup()
 	set_icon(shell, 1);
 	form = XtCreateManagedWidget("keyform", xmFormWidgetClass,
 			shell, NULL, 0);
-	XtAddCallback(form, XmNhelpCallback, help_callback, (XtPointer)"key");
+	XtAddCallback(form, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key");
 
 							/*-- mode --*/
 	n = 0;
@@ -92,7 +95,7 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNtopOffset,		16);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("Search mode:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Search mode:"), xmLabelWidgetClass,
 			form, args, n);
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_FORM);		n++;
@@ -109,24 +112,26 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		False);			n++;
-	w = XtCreateManagedWidget("Literal case sensitive",
+	w = XtCreateManagedWidget(_("Literal case sensitive"),
 			xmToggleButtonWidgetClass,
 			radio, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, mode_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"key_literal");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			mode_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_literal");
 
 	n = 0;
 	XtSetArg(args[n], XmNselectColor,	color[COL_TOGGLE]);	n++;
 	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		True);			n++;
-	w = XtCreateManagedWidget("Literal case insensitive",
+	w = XtCreateManagedWidget(_("Literal case insensitive"),
 			xmToggleButtonWidgetClass,
 			radio, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, mode_callback, (XtPointer)1);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"key_uncase");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			mode_callback, (XtPointer)1);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_uncase");
 
 #ifndef NOREGEX
 	n = 0;
@@ -134,12 +139,13 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNindicatorType,	XmONE_OF_MANY);		n++;
 	XtSetArg(args[n], XmNhighlightThickness,0);			n++;
 	XtSetArg(args[n], XmNset,		False);			n++;
-	w = XtCreateManagedWidget("Regular expression",
+	w = XtCreateManagedWidget(_("Regular expression"),
 			xmToggleButtonWidgetClass,
 			radio, args, n);
-	XtAddCallback(w, XmNvalueChangedCallback, mode_callback, (XtPointer)2);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"key_regular");
+	XtAddCallback(w, XmNvalueChangedCallback, (XtCallbackProc)
+			mode_callback, (XtPointer)2);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_regular");
 #endif
 
 	XtManageChild(radio);
@@ -150,10 +156,10 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNtopOffset,		16);			n++;
 	XtSetArg(args[n], XmNleftAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNleftOffset,	16);			n++;
-	w = XtCreateManagedWidget("Search for:", xmLabelWidgetClass,
+	w = XtCreateManagedWidget(_("Search for:"), xmLabelWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"key_string");
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_string");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -169,10 +175,10 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNbackground,	color[COL_TEXTBACK]);	n++;
 	text = XtCreateManagedWidget("", xmTextWidgetClass,
 			form, args, n);
-	XtAddCallback(text, XmNactivateCallback, text_callback,
-						(XtPointer)NULL);
-	XtAddCallback(text, XmNhelpCallback, help_callback,
-						(XtPointer)"key_string");
+	XtAddCallback(text, XmNactivateCallback, (XtCallbackProc)
+			text_callback, (XtPointer)NULL);
+	XtAddCallback(text, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_string");
 
 							/*-- buttons --*/
 	n = 0;
@@ -182,11 +188,12 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNrightAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNrightOffset,	16);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Search", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Search"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, search_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"key_search");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			search_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_search");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -198,11 +205,12 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	16);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Cancel", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Cancel"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, done_callback, (XtPointer)0);
-	XtAddCallback(w, XmNhelpCallback, help_callback,
-						(XtPointer)"key_cancel");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			done_callback, (XtPointer)0);
+	XtAddCallback(w, XmNhelpCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key_cancel");
 
 	n = 0;
 	XtSetArg(args[n], XmNtopAttachment,	XmATTACH_WIDGET);	n++;
@@ -214,15 +222,17 @@ void create_keyword_popup()
 	XtSetArg(args[n], XmNbottomAttachment,	XmATTACH_FORM);		n++;
 	XtSetArg(args[n], XmNbottomOffset,	16);			n++;
 	XtSetArg(args[n], XmNwidth,		80);			n++;
-	w = XtCreateManagedWidget("Help", xmPushButtonWidgetClass,
+	w = XtCreateManagedWidget(_("Help"), xmPushButtonWidgetClass,
 			form, args, n);
-	XtAddCallback(w, XmNactivateCallback, help_callback, (XtPointer)"key");
-	XtAddCallback(w, XmNhelpCallback,     help_callback, (XtPointer)"key");
+	XtAddCallback(w, XmNactivateCallback, (XtCallbackProc)
+			help_callback, (XtPointer)"key");
+	XtAddCallback(w, XmNhelpCallback,     (XtCallbackProc)
+			help_callback, (XtPointer)"key");
 
 	XtPopup(shell, XtGrabNone);
 	closewindow = XmInternAtom(display, "WM_DELETE_WINDOW", False);
-	XmAddWMProtocolCallback(shell, closewindow,
-					done_callback, (XtPointer)shell);
+	XmAddWMProtocolCallback(shell, closewindow, (XtCallbackProc)
+			done_callback, (XtPointer)shell);
 
 	have_shell = TRUE;
 }
@@ -234,30 +244,30 @@ void create_keyword_popup()
  */
 
 /*ARGSUSED*/
-static void mode_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void mode_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	search_mode = item;
 }
 
 
 /*ARGSUSED*/
-static void done_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void done_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	destroy_keyword_popup();
 }
 
 
 /*ARGSUSED*/
-static void search_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void search_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (search_string)
 		XtFree(search_string);
@@ -269,10 +279,10 @@ static void search_callback(widget, item, data)
 
 
 /*ARGSUSED*/
-static void text_callback(widget, item, data)
-	Widget				widget;
-	int				item;
-	XmToggleButtonCallbackStruct	*data;
+static void text_callback(
+	Widget				widget,
+	int				item,
+	XmToggleButtonCallbackStruct	*data)
 {
 	if (search_string)
 		XtFree(search_string);
