@@ -69,7 +69,6 @@ typedef struct Acl {
 } Acl;
 
 static Acl		*acl_root;	/* root of current access list */
-static char		*acl_fname;	/* file name pf acl file opened */
 static char		*word;		/* current word from input stream */
 static char		*nextword;	/* next word from input (readahead) */
 
@@ -191,6 +190,7 @@ int acl_read(
 				break;
 
 			  case aUSERHOST:
+			        acl->mode = aUSER; /* GU: preparing for next word */ 
 				*c++ = 0;
 				if (*word >= '0' && *word <= '9')
 					usr = atoi(word);
@@ -233,7 +233,7 @@ int acl_read(
 		if (!acl->read && !acl->write && !acl->delete)
 			acl->read = acl->write = acl->delete = TRUE;
 	fclose(fp);
-	if (!(acl_fname = mystrdup(fname))) {
+	if (!fname) {
 		perror(fname);
 		ret = FALSE;
 	}
@@ -281,7 +281,7 @@ static void acl_add_data(
 #define ISWORD(c) (c >= 'a' && c <= 'z' ||\
 		   c >= 'A' && c <= 'Z' ||\
 		   c >= '0' && c <= '9' ||\
-		   c == '_' || c == '.' || c == '-')
+		   c == '_' || c == '.' || c == '-' || c == '@')
 
 static BOOL getword(
 	FILE		*fp)		/* file to read from */
