@@ -25,7 +25,6 @@ extern GC		gc;		/* everybody uses this context */
 extern Pixel		color[NCOLS];	/* colors: COL_* */
 extern Pixel		bkcolor;	/* background color (COL_*) */
 static Widget		mainwindow;	/* for popdown/popup by snooze */
-static XtIntervalId	timer_id;	/* identifies snooze timer */
 
 
 void create_widgets(
@@ -175,5 +174,5 @@ static void snooze_callback(
 {
 	XtPopdown(XtParent(mainwindow));
 	XtUnmapWidget(XtParent(mainwindow));
-	timer_id = XtAppAddTimeOut(app, SNOOZE_PERIOD, timer_callback, 0);
+	XtAppAddTimeOut(app, SNOOZE_PERIOD, timer_callback, 0);
 }
