@@ -702,8 +702,24 @@ static int Print_Day(
 		fprintf(fp, "	");
 
 		if (config.pr_color) {
-			int color = entry->acolor ? COL_HBLACK+entry->acolor-1
-						  : COL_WNOTE;
+			int color;
+
+			if (u > 0) {
+				double r, g, b;
+				color = COL_WUSER_0 + (user[u].color & 7);
+				r = xcolor[color].red   / 65536.;
+				g = xcolor[color].green / 65536.;
+				b = xcolor[color].blue  / 65536.;
+				if(user[u].color > 7) {
+					r = (r + 1) / 2;
+					g = (g + 1) / 2;
+					b = (b + 1) / 2;
+				}
+				fprintf(fp, "%g %g %g setrgbcolor ", r, g, b);
+				fprintf(fp, "PaintBGRect\n	");
+			}
+			color = entry->acolor ? COL_HBLACK+entry->acolor-1
+					      : COL_WNOTE;
 			fprintf(fp, "%g %g %g setrgbcolor ",
 				xcolor[color].red   / 65536.,
 				xcolor[color].green / 65536.,
