@@ -23,7 +23,6 @@ extern char *mystrdup(			/* strdup replacement for Ultrix */
 	register char *s);
 extern void exit(			/* local version of exit w/ writeback*/
 	int		ret);
-#ifndef VARARGS
 extern void fatal(			/* print error message and exits */
 	char		*fmt, ...);
 extern void print_button(		/* print a string into label or but */
@@ -32,28 +31,6 @@ extern void print_button(		/* print a string into label or but */
 extern void print_text_button(		/* print a string into a Text button */
 	Widget		w,
 	char		*fmt, ...);
-#else
-extern void fatal(			/* prints an error message and exits */
-	char	*fmt,
-	int	a,
-	int	b,
-	int	c,
-	int	d);
-extern void print_button(		/* print a string into label or but */
-	Widget		w,
-	char		*fmt,
-	int		a,
-	int		b,
-	int		c,
-	int		d);
-extern void print_text_button(		/* print a string into a Text button */
-	Widget		w,
-	char		*fmt,
-	int		a,
-	int		b,
-	int		c,
-	int		d);
-#endif
 #ifdef MIPS
 extern char *getenv(const char *);
 extern char *malloc(size_t);
@@ -191,6 +168,7 @@ extern void help_callback(		/* print help for a topic */
 extern char *parse_holidays(		/* eval holiday defs for <year> */
 	int		year,		/* year to parse for, 0=1970 */
 	BOOL		force);		/* file has changed, re-read */
+extern void reset_all_hdays(void);	/* delete all known holidays */
 extern void seteaster(			/* set a holiday relative to Easter */
 	int		off,		/* offset in days */
 	int		length,		/* length in days */
@@ -291,21 +269,10 @@ extern void multiple_writer_warning_popup( /* create write warning popup */
 	Widget		widget);	/* install near this widget */
 extern void new_language_popup(		/* selected new language */
 	Widget		widget);	/* install near this widget */
-#ifndef VARARGS
 extern void create_error_popup(
 	Widget		widget,
 	int		error,
 	char		*fmt, ...);
-#else
-extern void create_error_popup(		/* create error popup with Unix error*/
-	void		*widget,
-	int		error,
-	char		*fmt,
-	int		a,
-	int		b,
-	int		c,
-	int		d);
-#endif
 
 /*---------------------------------------- print.c ------------*/
 
@@ -395,7 +362,7 @@ extern void create_recycle_popup(void);	/* create a recycle popup */
 /*---------------------------------------- daymenu.c ------------*/
 
 extern void destroy_all_listmenus(void);/* destroy all list menus */
-extern void update_all_listmenus(void);	/* redraw all list menus */
+extern void update_all_listmenus(BOOL);	/* redraw (opt.reeval) all list menus*/
 extern void create_entry_widgets(	/* creates all widgets in a list menu*/
 	struct listmenu	*w,
 	int		nentries);
