@@ -248,7 +248,7 @@ static BOOL accept_new_list(void)
 	write_mainlist();
 	if (!read_mainlist())
 		return(FALSE);
-	update_all_listmenus();
+	update_all_listmenus(TRUE);
 	redraw_all_views();
 	resynchronize_daemon();
 	return(TRUE);
@@ -705,7 +705,6 @@ static void got_user_text(
 	int			y,		/* row, y=0: title */
 	char			*string)	/* text entered by user */
 {
-	struct passwd		*pw;		/* for searching home dirs */
 	register struct user	*u;
 	char			buf[100], *p;
 	int			i;
@@ -771,7 +770,7 @@ static void got_user_text(
 	}
 							/* default path? */
 	if (u->name && *u->name && !u->path) {
-		if (pw = getpwnam(u->name)) {
+		if (getpwnam(u->name)) {
 			sprintf(buf, "~%s", u->name);
 			u->path = mystrdup(buf);
 		} else {
