@@ -27,11 +27,7 @@
 #include <time.h>
 #include <errno.h>
 #include <sys/types.h>
-#ifdef VARARGS
-#include <varargs.h>
-#else
 #include <stdarg.h>
-#endif
 #if defined(IBM) || defined(ULTRIX)
 #include <fcntl.h>
 #else
@@ -80,8 +76,10 @@ char *resolve_tilde(
 
 	if (!path[1] || path[1] == '/') {
 		*pathbuf = 0;
-		if (!(home = getenv("HOME")))
-			home = getenv("home");
+		if (!(home = getenv("HOME")) &&
+		    !(home = getenv("home")))
+			fprintf(stderr, _("%s: $HOME and $home not set,\n"),
+								progname);
 	} else {
 		for (p=path+1, q=pathbuf; *p && *p != '/'; p++, q++)
 			*q = *p;
@@ -334,12 +332,9 @@ _("%s: failed to lock database after 3 seconds, accessing anyway\n"), progname);
 
 /*
  * whenever something goes seriously wrong, this routine is called. It makes
- * code easier to read. fatal() never returns. This may fail horribly if
- * VARARGS is defined, but at least it's going to do *something*.
+ * code easier to read. fatal() never returns.
  */
 
-#ifndef VARARGS
-/*VARARGS*/
 void fatal(
 	char		*fmt, ...)
 {
@@ -353,21 +348,6 @@ void fatal(
 	exit(1);
 }
 
-#else
-/*VARARGS*/
-void fatal(
-	char	*fmt,
-	int	a,
-	int	b,
-	int	c,
-	int	d)
-{
-	fprintf(stderr, fmt, a, b, c, d);
-	putc('\n', stderr);
-	exit(1);
-}
-#endif
-
 
 /*
  * Ultrix doesn't have strdup, so we'll need to define one locally.
