@@ -572,9 +572,9 @@ int truncate_strpack(
 }
 
 void g_draw_strpack(
-	strpack			*partialstr,
 	int			x,
-	int			y)
+	int			y,
+	strpack			*partialstr)
 {
 	strpack			*upperpartstr;
 
