@@ -20,11 +20,7 @@
 #include <stdlib.h>
 #include <time.h>
 #include <assert.h>
-#ifdef VARARGS
-#include <varargs.h>
-#else
 #include <stdarg.h>
-#endif
 #include <Xm/Xm.h>
 #include <Xm/Text.h>
 #include <X11/StringDefs.h>
@@ -239,7 +235,6 @@ void truncate_string(
  * the gall to ship a pre-ansi compiler unless you pay extra...
  */
 
-#ifndef VARARGS
 void print_button(
 	Widget		w,
 	char		*fmt, ...)
@@ -276,51 +271,6 @@ void print_text_button(
 	}
 }
 
-#else /* VARARGS */
-
-void print_button(
-	Widget		w,
-	char		*fmt,
-	int		a,
-	int		b,
-	int		c,
-	int		d)
-{
-	Arg		args;
-	XmString	string;
-	char		buf[1024];
-
-	if (fmt && w) {
-		sprintf(buf, fmt, a, b, c, d);
-		string = XmStringCreateSimple(buf);
-		XtSetArg(args, XmNlabelString, string);
-		XtSetValues(w, &args, 1);
-		XmStringFree(string);
-	}
-}
-
-void print_text_button(
-	Widget		w,
-	char		*fmt,
-	int		a,
-	int		b,
-	int		c,
-	int		d)
-{
-	XmString	string;
-	char		buf[1024];
-
-	if (w) {
-		sprintf(buf, fmt, a, b, c, d);
-		string = XmStringCreateSimple(buf);
-		XmTextSetString(w, *buf ? buf : " ");
-		XmTextSetInsertionPosition(w, strlen(buf));
-		XmStringFree(string);
-	}
-}
-#endif /* VARARGS */
-
-
 
 /*
  * draw a pixmap into a button, or remove the pixmap. The button must have
@@ -650,7 +600,7 @@ static void canvas_callback(
 			else {
 				drag_entry(dc->view, mode, time0, time);
 				confirm_new_entry();
-				update_all_listmenus();
+				update_all_listmenus(TRUE);
 				redraw_all_views();
 			}
 			moving = FALSE;
