@@ -12,10 +12,12 @@
 #include <Xm/Xm.h>
 #include "cal.h"
 
-static void set_year_day_bkg_color(), draw_year_day_notes();
-static void draw_year_daybox(), draw_year_month();
-static BOOL yearpos_to_day_month(), day_to_yearpos();
-void draw_year_day();
+static void draw_year_month	(int, int, int, int);
+static void draw_year_daybox	(int, int, int, int, int);
+static void draw_year_day_notes	(int, int, int, BOOL);
+static void set_year_day_bkg_color(int, int, int);
+static BOOL day_to_yearpos	(int *, int *, int, int, int);
+static BOOL yearpos_to_day_month(int *, int *, BOOL *, BOOL *, int, int);
 
 static int		qx,qy,qxs,qys;	/* pos and size of quit button */
 
@@ -48,8 +50,9 @@ extern short monthlen[];
  * Also, create a day popup menu.
  */
 
-int clicked_year_calendar(x, y)
-	int		x, y;		/* pixel pos clicked */
+int clicked_year_calendar(
+	int		x,		/* pixel pos clicked */
+	int		y)
 {
 	int		day, month;
 	BOOL		callweek;	/* if TRUE, pop up week view */
@@ -95,8 +98,8 @@ int clicked_year_calendar(x, y)
  * draw the entire year menu
  */
 
-void draw_year_calendar(region)
-	Region region;
+void draw_year_calendar(
+	Region			region)
 {
 	register struct config	*c = &config;
 	Window			window;
@@ -118,12 +121,12 @@ void draw_year_calendar(region)
 
 	set_color(COL_YGRID);				/* quit button */
 	qx  = qy = 10;
-	qxs = 10 + strlen_in_pixels("Done", FONT_STD);
+	qxs = 10 + strlen_in_pixels(_("Done"), FONT_STD);
 	qys =  4 + font[FONT_STD]->max_bounds.ascent;
 	XDrawRectangle(display, window, gc, qx, qy, qxs, qys);
 	XSetFont(display, gc, font[FONT_STD]->fid);
 	XDrawString(display, window, gc,
-		qx+5, qy+font[FONT_STD]->max_bounds.ascent, "Done", 4);
+		qx+5, qy+font[FONT_STD]->max_bounds.ascent, _("Done"), 4);
 
 	sprintf(buf, "%d", 1900 + curr_year);		/* year number */
 	set_color(COL_YTITLE);
@@ -153,14 +156,17 @@ void draw_year_calendar(region)
  * draw entire month at the specified position
  */
 
-static void draw_year_month(month, year, x, y)
-	int			month, year;
-	int			x, y;
+static void draw_year_month(
+	int			month,
+	int			year,
+	int			x,
+	int			y)
 {
 	register struct config	*c = &config;
 	Window			window = XtWindow(mainmenu.yearcal);
 	XPoint			point[4];
 	int			i, j;
+	char			*mn;
 
 							/* days */
 	for (i=1; i < 32; i++)
@@ -169,19 +175,20 @@ static void draw_year_month(month, year, x, y)
 							/* month name */
 	set_color(COL_YMONTH);
 	XSetFont(display, gc, font[FONT_YMONTH]->fid);
+	mn = monthname[month];
 	XDrawString(display, window, gc,
-			x, y + c->yearbox_ys * 3/4,
-			monthname[month], strlen(monthname[month]));
+			x, y + c->yearbox_ys * 3/4, mn, strlen(mn));
 
 							/* weekday names */
 	j = c->sunday_first ? 6 : 0;
 	set_color(COL_YWEEKDAY);
 	XSetFont(display, gc, font[FONT_YDAY]->fid);
-	for (i=0; i < 7; i++, j++)
+	for (i=0; i < 7; i++, j++) {
+		char *wdn = _(weekday_name[j%7]);
 		XDrawString(display, window, gc,
 				x + i * c->yearbox_xs, y + c->yearbox_ys * 7/4,
-				weekday_name[j%7], strlen(weekday_name[j%7]));
-
+				wdn, strlen(wdn));
+	}
 							/* month box */
 	set_color(COL_YGRID);
 	XDrawRectangle(display, window, gc, x-1, y-1 + 2*c->yearbox_ys,
@@ -218,10 +225,10 @@ static void draw_year_month(month, year, x, y)
  * internal use; it requires a X/Y coordinate.
  */
 
-void draw_year_day(day, month, year)
-	int			day;		/* 1..31 */
-	int			month;		/* 0..11 */
-	int			year;		/* year since 1900 */
+void draw_year_day(
+	int			day,		/* 1..31 */
+	int			month,		/* 0..11 */
+	int			year)		/* year since 1900 */
 {
 	register struct config	*c = &config;
 
@@ -235,10 +242,12 @@ void draw_year_day(day, month, year)
 				2*c->yearbox_ys);
 }
 
-static void draw_year_daybox(day, month, year, x, y)
-	int			day;		/* 1..31 */
-	int			month, year;
-	int			x, y;		/* upper right of first day */
+static void draw_year_daybox(
+	int			day,		/* 1..31 */
+	int			month,
+	int			year,
+	int			x,		/* upper right of first day */
+	int			y)
 {
 	Window			window = XtWindow(mainmenu.yearcal);
 	int			dx, dy;		/* position in calendar */
@@ -281,11 +290,11 @@ static void draw_year_daybox(day, month, year, x, y)
  * the moment, it's O(n^2).
  */
 
-static void draw_year_day_notes(day, month, year, ifyes)
-	int			day;		/* 1..31 */
-	int			month;		/* 0..11 */
-	int			year;		/* year since 1900 */
-	BOOL			ifyes;		/* only draw, never undraw */
+static void draw_year_day_notes(
+	int			day,		/* 1..31 */
+	int			month,		/* 0..11 */
+	int			year,		/* year since 1900 */
+	BOOL			ifyes)		/* only draw, never undraw */
 {
 	register struct config	*c = &config;
 	struct lookup		lookup;		/* result of entry lookup */
@@ -341,9 +350,10 @@ static void draw_year_day_notes(day, month, year, ifyes)
 }
 
 
-static void set_year_day_bkg_color(day, month, year)
-	int			day;		/* 1..31 */
-	int			month, year;
+static void set_year_day_bkg_color(
+	int		day,		/* 1..31 */
+	int		month,
+	int		year)
 {
 	struct tm *tm = time_to_tm(get_time());
 	set_color(day   == tm->tm_mday &&
@@ -353,12 +363,14 @@ static void set_year_day_bkg_color(day, month, year)
 
 
 /*-------------------------------------------------- low-level --------------*/
-static BOOL day_to_yearpos(x, y, day, month, year)
-	int			*x, *y;		/* returned box, 0..6/0..5 */
-	int			day;		/* 1..31 */
-	int			month, year;
+static BOOL day_to_yearpos(
+	int		*x,		/* returned box, 0..6/0..5 */
+	int		*y,
+	int		day,		/* 1..31 */
+	int		month,
+	int		year)
 {
-	int			wkday;
+	int		wkday;
 
 	if (!date_to_time(day, month, year, &wkday, 0, 0))
 		return(FALSE);
@@ -375,12 +387,13 @@ static BOOL day_to_yearpos(x, y, day, month, year)
  * week row, set *callweek and return the first day of that week.
  */
 
-static BOOL yearpos_to_day_month(day, month, callweek, callday, x, y)
-	int			*day;		/* returned day#, 1..31 or 0*/
-	int			*month;		/* returned month #, 0..11 */
-	BOOL			*callweek;	/* if TRUE, pop up week view*/
-	BOOL			*callday;	/* if TRUE, pop up day view */
-	int			x, y;		/* pixel pos in drawable */
+static BOOL yearpos_to_day_month(
+	int			*day,		/* returned day#, 1..31 or 0*/
+	int			*month,		/* returned month #, 0..11 */
+	BOOL			*callweek,	/* if TRUE, pop up week view*/
+	BOOL			*callday,	/* if TRUE, pop up day view */
+	int			x,		/* pixel pos in drawable */
+	int			y)
 {
 	register struct config	*c = &config;
 	int			dx, dy;		/* month box size, with gap */
