@@ -9,7 +9,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <time.h>
-#include <varargs.h>
 #include <Xm/Xm.h>
 #include <Xm/DialogS.h>
 #include <Xm/Form.h>
@@ -423,7 +422,7 @@ static void sync_callback(
 	}
 	read_mainlist();
 	build_yov(FALSE);
-	update_all_listmenus();
+	update_all_listmenus(TRUE);
 	redraw_all_views();
 }
 
